



import os
import typing

import jk_typing
#import jk_prettyprintobj

from .Context import Context






class _INode:

	################################################################################################################################
	## Constructor
	################################################################################################################################

	################################################################################################################################
	## Public Properties
	################################################################################################################################

	################################################################################################################################
	## Helper Methods
	################################################################################################################################

	################################################################################################################################
	## Public Methods
	################################################################################################################################

	def initialize(self, ctx:Context):
		raise NotImplementedError()
	#

#






